from .main import run_sync

# run the main program

if __name__ == "__main__":
    run_sync()
